@@ -18,8 +18,10 @@
 #include "includefirst.hpp"
 
 #include "basegdl.hpp"
-#include "nullgdl.hpp"
-#include "objects.hpp"
+#include "objects.hpp" //for UseSmartTpool
+#ifndef _WIN32
+#include "shm_utils.hpp"
+#endif
 
 using namespace std;
 
@@ -53,7 +55,11 @@ BaseGDL& BaseGDL::operator=(const BaseGDL& right)
   this->dim = right.dim;
   return *this;
 }
-
+//Only used in "relaxed assignment for struct copying 
+BaseGDL& BaseGDL::operator<<=(const BaseGDL& right)
+{
+return *this; // just DO NOTHING. It seems the best solution (one-liner) to #2124 // throw GDLException("BaseGDL::operator<<=(const BaseGDL& right) called.");
+}
 void  BaseGDL::InitFrom(const BaseGDL& right)
 {
   throw GDLException("BaseGDL::InitFrom(const BaseGDL& right) called.");
@@ -152,6 +158,7 @@ std::istream& BaseGDL::FromStream(std::istream& i)
 bool BaseGDL::Scalar() const { return false;}
 bool BaseGDL::StrictScalar() const { return false;}
 DType   BaseGDL::Type() const { return GDL_UNDEF;}
+int BaseGDL::SizeOfType() const {return 0;}
 const std::string& BaseGDL::TypeStr() const
 { static const std::string s("UNDEFINED"); return s;}
 bool BaseGDL::EqType( const BaseGDL*) const
@@ -528,7 +535,7 @@ SizeT BaseGDL::OFmtI( std::ostream* os, SizeT offs, SizeT num, int width, int mi
 SizeT BaseGDL::IFmtCal( std::istream* is, SizeT offs, SizeT r, int width, BaseGDL::Cal_IOMode cMode)
 {throw GDLException("BaseGDL::IFmtCal(...) called.");}
 
-SizeT BaseGDL::OFmtCal( std::ostream* os, SizeT offs, SizeT num, int width, int minN, char *f, int code, BaseGDL::Cal_IOMode oM)
+SizeT BaseGDL::OFmtCal( std::ostream* os, SizeT offs, SizeT num, int width, int minN, const std::string &s, int code, BaseGDL::Cal_IOMode oM)
 {throw GDLException("BaseGDL::OFmtCal(...) called.");}
 
 SizeT BaseGDL::IFmtA( std::istream* is, SizeT offset, SizeT num, int width)
@@ -840,7 +847,15 @@ void GDLDelete( BaseGDL* toDelete)
 {
   if( toDelete ==NULL) return;
   if( toDelete == NullGDL::GetSingleInstance()) return;
-  delete toDelete;
+  if (!toDelete->IsShared())  
+  { 
+    if(toDelete->GetCallbackFunction()!=NULL) toDelete->GetCallbackFunction()((unsigned char*)toDelete->DataAddr());
+  //if (toDelete->callback_function!=NULL) toDelete->callback_function((unsigned char*)toDelete->DataAddr());
+  else delete toDelete; 
+  }
+#ifndef _WIN32
+  else lib::shm_unreference(toDelete);
+#endif
 }
 int GDL_NTHREADS=1;
 
