@@ -20,11 +20,29 @@
 
 #include "includefirst.hpp"
 
-//#include <list>
-#if defined(__CYGWIN__) || defined(_WIN32)
-#  include <rpc/xdr.h>
+//use libtirpc (to be installed) for linux & mac, use portablexdr for windows, but use our custom 'xdr.h' 
+#if defined(_WIN32)
+#include "types.h"
+#include "xdr.h"
+#define u_int64_t uint64_t
+#define u_int32_t uint32_t
+#define u_int16_t uint16_t
+#define xdr_int8_t xdr_char
+#define xdr_u_int8_t xdr_u_char
+#define xdr_uint8_t xdr_short
+#define xdr_int16_t xdr_short
+#define xdr_u_int16_t xdr_u_short
+#define xdr_uint16_t xdr_u_short
+#define xdr_int32_t xdr_int
+#define xdr_u_int32_t xdr_u_int
+#define xdr_uint32_t xdr_u_int
 #else
-#  include <rpc/rpc.h>
+#include <rpc/rpc.h>
+#ifdef __APPLE__
+#define xdr_uint16_t xdr_u_int16_t
+#define xdr_uint32_t xdr_u_int32_t
+#define xdr_uint64_t xdr_u_int64_t
+#endif
 #endif
 
 #include <algorithm>
@@ -345,7 +363,7 @@ public:
 #if defined(HAVE_MALLOC_ZONE_STATISTICS) && defined(HAVE_MALLOC_MALLOC_H)
 // - the sbrk(0) does not give any meaningfull info for HIGHWATER
 // - using mallinfo() frequently gives a large performace loss
-    UpdateCurrent(); // updates the highwater mark 
+// avoid doing this here, explains the slowness on OSX  //   UpdateCurrent(); // updates the highwater mark 
 #endif
   }
 
@@ -385,9 +403,11 @@ public:
 
 protected:
   dimension dim;
-  
+  bool shared=false;
+  void (* callback_function)(unsigned char*)=NULL;
+
 public:
-  // type of initalization
+  // type of initialization
   enum InitType {
     ZERO=0,
     NOZERO,
@@ -446,7 +466,12 @@ public:
   BaseGDL();//: dim() {} 
   explicit BaseGDL(const dimension& dim_);//: dim(dim_) {} 
 
-
+  //callback function when deleted
+  void SetCallbackFunction(void (* ptr)(unsigned char*)){callback_function=ptr;}
+  void (*GetCallbackFunction())(unsigned char*){return callback_function;}
+  //shared
+  bool IsShared() {return shared;}
+  void SetShared() {shared=true;} //used only with shmvar variables, explicitely in theur creation.
   // provide access to dim member
   inline const dimension& Dim()   const      { return dim;}
   inline SizeT    Dim(SizeT d)    const      { return dim[d];}
@@ -466,6 +491,7 @@ public:
 
 //  private:
   virtual BaseGDL& operator=(const BaseGDL& right);
+  virtual BaseGDL& operator<<=(const BaseGDL& right); //for DStructGDL only
 //  public:
  
   virtual void InitFrom(const BaseGDL& right); // for structs
@@ -515,6 +541,7 @@ public:
   virtual bool Scalar() const;
   virtual bool StrictScalar() const;
   virtual DType   Type() const;
+  virtual int   SizeOfType() const;
   virtual const std::string& TypeStr() const;
   virtual bool          EqType( const BaseGDL*) const;
   virtual void* DataAddr();// SizeT elem=0);
@@ -712,7 +739,7 @@ public:
   virtual SizeT OFmtA( std::ostream* os, SizeT offset, SizeT num, int width, int code);
   virtual SizeT OFmtF( std::ostream* os, SizeT offs, SizeT num, int width, int prec, const int code=0, const BaseGDL::IOMode oM = FIXED); 
   virtual SizeT OFmtI( std::ostream* os, SizeT offs, SizeT num, int width, int minN, int code=0, BaseGDL::IOMode oM = DEC);
-  virtual SizeT OFmtCal( std::ostream* os, SizeT offs, SizeT num, int width, int minN, char *fill, int code=0, BaseGDL::Cal_IOMode oM = DEFAULT);
+  virtual SizeT OFmtCal( std::ostream* os, SizeT offs, SizeT num, int width, int minN, const std::string &s, int code=0, BaseGDL::Cal_IOMode oM = DEFAULT);
   virtual SizeT IFmtA( std::istream* is, SizeT offset, SizeT num, int width);
   virtual SizeT IFmtF( std::istream* is, SizeT offs, SizeT num, int width);
   virtual SizeT IFmtI( std::istream* is, SizeT offs, SizeT num, int width, 
