@@ -18,7 +18,6 @@ datatypesref.cpp  -  specializations for DPtrGDL and DObjGDL for reference count
 // to be included from datatypes.cpp
 #ifdef INCLUDE_DATATYPESREF_CPP
 #undef INCLUDE_DATATYPESREF_CPP
-#include "nullgdl.hpp"
 
 // reference counting for INIT
 template<>
@@ -29,7 +28,7 @@ Data_<SpDPtr>* Data_<SpDPtr>::New( const dimension& dim_, BaseGDL::InitType noZe
     {
       Data_* res =  new Data_(dim_, BaseGDL::NOZERO);
       SizeT nEl = res->dd.size();
-      /*#pragma omp parallel if (nEl >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nEl))
+      /*#pragma omp parallel if (nEl >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nEl))
 	{
 	#pragma omp for*/
       for( OMPInt i=0; i<nEl; ++i) (*res)[ i] = (*this)[ 0]; // set all to scalar
@@ -49,7 +48,7 @@ Data_<SpDObj>* Data_<SpDObj>::New( const dimension& dim_, BaseGDL::InitType noZe
     {
       Data_* res =  new Data_(dim_, BaseGDL::NOZERO);
       SizeT nEl = res->dd.size();
-      /*#pragma omp parallel if (nEl >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nEl))
+      /*#pragma omp parallel if (nEl >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nEl))
 	{
 	#pragma omp for*/
       for( OMPInt i=0; i<nEl; ++i) (*res)[ i] = (*this)[ 0]; // set all to scalar
@@ -116,6 +115,7 @@ void Data_<SpDPtr>::InsAt( Data_* srcIn, ArrayIndexListT* ixList, SizeT offset)
   nDim--;
 
   dimension srcDim=srcIn->Dim();
+  srcDim.Purge(); // newly inserted: variant of ticket #675
   SizeT len=srcDim[0]; // length of one segment to copy (one line of srcIn)
 
   //  SizeT nDim   =RankIx(ixDim.Rank());
@@ -131,11 +131,11 @@ void Data_<SpDPtr>::InsAt( Data_* srcIn, ArrayIndexListT* ixList, SizeT offset)
   SizeT nCp=srcIn->Stride(nDim+1)/len; // number of OVERALL copy actions
 
   // as lines are copied, we need the stride from 2nd dim on
-  SizeT retStride[MAXRANK];
+  SizeT retStride[MAXRANK+1];
   for( SizeT a=0; a <= nDim; ++a) retStride[a]=srcDim.Stride(a+1)/len;
 	
   // a magic number, to reset destStart for this dimension
-  SizeT resetStep[MAXRANK];
+  SizeT resetStep[MAXRANK+1];
   for( SizeT a=1; a <= nDim; ++a)
     resetStep[a]=(retStride[a]-1)/retStride[a-1]*this->dim.Stride(a);
 	
@@ -231,6 +231,7 @@ void Data_<SpDObj>::InsAt( Data_* srcIn, ArrayIndexListT* ixList, SizeT offset)
   nDim--;
 
   dimension srcDim=srcIn->Dim();
+  srcDim.Purge(); // newly inserted: variant of ticket #675
   SizeT len=srcDim[0]; // length of one segment to copy (one line of srcIn)
 
   //  SizeT nDim   =RankIx(ixDim.Rank());
@@ -340,7 +341,7 @@ void Data_<SpDPtr>::AssignAt( BaseGDL* srcIn, ArrayIndexListT* ixList, SizeT off
 
 	  GDLInterpreter::AddRef( scalar, nCp);
 
-	  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+	  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
 	  {
 	    //#pragma omp for
 	    for( SizeT c=0; c<nCp; ++c)
@@ -358,7 +359,7 @@ void Data_<SpDPtr>::AssignAt( BaseGDL* srcIn, ArrayIndexListT* ixList, SizeT off
 	  
 	  GDLInterpreter::AddRef( scalar, nCp);
 
-	  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+	  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
 	  {
 	    //#pragma omp for
 	    for( SizeT c=0; c<nCp; ++c)
@@ -383,7 +384,7 @@ void Data_<SpDPtr>::AssignAt( BaseGDL* srcIn, ArrayIndexListT* ixList, SizeT off
 	    else
 	      throw GDLException("Source expression contains not enough elements.");
 	  }
-	  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+	  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
 	  {
 	    //#pragma omp for
 	    for( SizeT c=0; c<nCp; ++c)
@@ -419,7 +420,7 @@ void Data_<SpDPtr>::AssignAt( BaseGDL* srcIn, ArrayIndexListT* ixList, SizeT off
 				       " source expression.");
 		  
 		  AllIxBaseT* allIx = ixList->BuildIx();
-		  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+		  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
 		  {
 		    //#pragma omp for
 		    for( SizeT c=0; c<nCp; ++c)
@@ -439,7 +440,7 @@ void Data_<SpDPtr>::AssignAt( BaseGDL* srcIn, ArrayIndexListT* ixList, SizeT off
 				       " source expression.");
 		  
 		  AllIxBaseT* allIx = ixList->BuildIx();
-		  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+		  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
 		  {
 		    //#pragma omp for
 		    for( SizeT c=0; c<nCp; ++c)
@@ -476,7 +477,7 @@ void Data_<SpDObj>::AssignAt( BaseGDL* srcIn, ArrayIndexListT* ixList, SizeT off
 
 	  GDLInterpreter::AddRefObj( scalar, nCp);
 
-	  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+	  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
 	  {
 	    //#pragma omp for
 	    for( SizeT c=0; c<nCp; ++c)
@@ -494,7 +495,7 @@ void Data_<SpDObj>::AssignAt( BaseGDL* srcIn, ArrayIndexListT* ixList, SizeT off
 	  
 	  GDLInterpreter::AddRefObj( scalar, nCp);
 
-	  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+	  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
 	  {
 	    //#pragma omp for
 	    for( SizeT c=0; c<nCp; ++c)
@@ -519,7 +520,7 @@ void Data_<SpDObj>::AssignAt( BaseGDL* srcIn, ArrayIndexListT* ixList, SizeT off
 	    else
 	      throw GDLException("Source expression contains not enough elements.");
 	  }
-	  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+	  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
 	  {
 	    //#pragma omp for
 	    for( SizeT c=0; c<nCp; ++c)
@@ -555,7 +556,7 @@ void Data_<SpDObj>::AssignAt( BaseGDL* srcIn, ArrayIndexListT* ixList, SizeT off
 				       " source expression.");
 		  
 		  AllIxBaseT* allIx = ixList->BuildIx();
-		  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+		  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
 		  {
 		    //#pragma omp for
 		    for( SizeT c=0; c<nCp; ++c)
@@ -575,7 +576,7 @@ void Data_<SpDObj>::AssignAt( BaseGDL* srcIn, ArrayIndexListT* ixList, SizeT off
 				       " source expression.");
 		  
 		  AllIxBaseT* allIx = ixList->BuildIx();
-		  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+		  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
 		  {
 		    //#pragma omp for
 		    for( SizeT c=0; c<nCp; ++c)
@@ -654,7 +655,7 @@ void Data_<SpDPtr>::AssignAt( BaseGDL* srcIn, ArrayIndexListT* ixList)
 	
 	  GDLInterpreter::AddRef( scalar, nCp);
 
-	  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+	  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
 	  {
 	    //#pragma omp for
 	    for( SizeT c=0; c<nCp; ++c)
@@ -683,7 +684,7 @@ void Data_<SpDPtr>::AssignAt( BaseGDL* srcIn, ArrayIndexListT* ixList)
 			       " source expression.");
 
 	  AllIxBaseT* allIx = ixList->BuildIx();
-	  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+	  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
 	  {
 	    //#pragma omp for
 	    for( SizeT c=0; c<nCp; ++c)
@@ -714,7 +715,7 @@ void Data_<SpDPtr>::AssignAt( BaseGDL* srcIn)
       SizeT nCp=Data_::N_Elements();
 	
       GDLInterpreter::AddRef( scalar, nCp);
-      //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+      //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
       {
 	//#pragma omp for
 	for( SizeT c=0; c<nCp; ++c)
@@ -737,7 +738,7 @@ void Data_<SpDPtr>::AssignAt( BaseGDL* srcIn)
       // if (non-indexed) src is smaller -> just copy its number of elements
       if( nCp > srcElem) nCp=srcElem;
 	
-      //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+      //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
       {
 	//#pragma omp for
 	for( SizeT c=0; c<nCp; ++c)
@@ -758,7 +759,6 @@ void Data_<SpDObj>::AssignAt( BaseGDL* srcIn, ArrayIndexListT* ixList)
 {
   assert( ixList != NULL);
 
-  //  breakpoint(); // gdbg can not handle breakpoints in template functions
   Data_* src = static_cast<Data_*>(srcIn);
 
   SizeT srcElem= src->N_Elements();
@@ -782,7 +782,7 @@ void Data_<SpDObj>::AssignAt( BaseGDL* srcIn, ArrayIndexListT* ixList)
 	
 	  GDLInterpreter::AddRefObj( scalar, nCp);
 
-	  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+	  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
 	  {
 	    //#pragma omp for
 	    for( SizeT c=0; c<nCp; ++c)
@@ -810,7 +810,7 @@ void Data_<SpDObj>::AssignAt( BaseGDL* srcIn, ArrayIndexListT* ixList)
 			       " source expression.");
 
 	  AllIxBaseT* allIx = ixList->BuildIx();
-	  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+	  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
 	  {
 	    //#pragma omp for
 	    for( SizeT c=0; c<nCp; ++c)
@@ -842,7 +842,7 @@ void Data_<SpDObj>::AssignAt( BaseGDL* srcIn)
 	
       GDLInterpreter::AddRefObj( scalar, nCp);
 	
-      //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+      //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
       {
 	//#pragma omp for
 	for( SizeT c=0; c<nCp; ++c)
@@ -865,7 +865,7 @@ void Data_<SpDObj>::AssignAt( BaseGDL* srcIn)
       // if (non-indexed) src is smaller -> just copy its number of elements
       if( nCp > srcElem) nCp=srcElem;
 	
-      //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+      //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
       {
 	//#pragma omp for
 	for( SizeT c=0; c<nCp; ++c)
@@ -897,7 +897,7 @@ Data_<SpDPtr>* Data_<SpDPtr>::Index( ArrayIndexListT* ixList)
 
   //  DataT& res_dd = res->dd;
   AllIxBaseT* allIx = ixList->BuildIx();
-  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
   {
     //#pragma omp for
     for( SizeT c=0; c<nCp; ++c)
@@ -926,7 +926,7 @@ Data_<SpDObj>* Data_<SpDObj>::Index( ArrayIndexListT* ixList)
 
   //  DataT& res_dd = res->dd;
   AllIxBaseT* allIx = ixList->BuildIx();
-  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
   {
     //#pragma omp for
     for( SizeT c=0; c<nCp; ++c)
@@ -955,7 +955,7 @@ void Data_<SpDPtr>::InsertAt( SizeT offset, BaseGDL* srcIn,
     {
       SizeT nCp=src->N_Elements();
 
-      //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+      //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
       {
 	//#pragma omp for
 	for( SizeT c=0; c<nCp; ++c)
@@ -972,7 +972,7 @@ void Data_<SpDPtr>::InsertAt( SizeT offset, BaseGDL* srcIn,
       SizeT nCp=ixList->N_Elements();
 
       AllIxBaseT* allIx = ixList->BuildIx();
-      //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+      //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
       {
 	//#pragma omp for
 	for( SizeT c=0; c<nCp; ++c)
@@ -1008,7 +1008,7 @@ void Data_<SpDPtr>::CatInsert( const Data_* srcArr, const SizeT atDim, SizeT& at
 
 #ifdef _OPENMP
   SizeT nEl = srcArr->N_Elements();
-  //#pragma omp parallel for if (nEl >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nEl))
+  //#pragma omp parallel for if (nEl >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nEl))
   for( SizeT c=0; c<nCp; ++c)
     {
       // set new destination pointer
@@ -1061,7 +1061,7 @@ void Data_<SpDObj>::InsertAt( SizeT offset, BaseGDL* srcIn,
     {
       SizeT nCp=src->N_Elements();
 
-      //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+      //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
       {
 	//#pragma omp for
 	for( SizeT c=0; c<nCp; ++c)
@@ -1078,7 +1078,7 @@ void Data_<SpDObj>::InsertAt( SizeT offset, BaseGDL* srcIn,
       SizeT nCp=ixList->N_Elements();
 
       AllIxBaseT* allIx = ixList->BuildIx();
-      //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+      //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
       {
 	//#pragma omp for
 	for( SizeT c=0; c<nCp; ++c)
@@ -1114,7 +1114,7 @@ void Data_<SpDObj>::CatInsert( const Data_* srcArr, const SizeT atDim, SizeT& at
 
 #ifdef _OPENMP
   SizeT nEl = srcArr->N_Elements();
-  //#pragma omp parallel for if (nEl >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nEl))
+  //#pragma omp parallel for if (nEl >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nEl))
   for( SizeT c=0; c<nCp; ++c)
     {
       // set new destination pointer
@@ -1179,7 +1179,7 @@ void Data_<SpDPtr>::Assign( BaseGDL* src, SizeT nEl)
     srcT = static_cast<Data_*>( src);
   }
 
-  //#pragma omp parallel if (nEl >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nEl))
+  //#pragma omp parallel if (nEl >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nEl))
   {
     //#pragma omp for
     for(long k=0; k < nEl; ++k)
@@ -1216,7 +1216,7 @@ void Data_<SpDObj>::Assign( BaseGDL* src, SizeT nEl)
     srcT = static_cast<Data_*>( src);
   }
 
-  //#pragma omp parallel if (nEl >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nEl))
+  //#pragma omp parallel if (nEl >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nEl))
   {
     //#pragma omp for
     for(long k=0; k < nEl; ++k)
@@ -1263,14 +1263,14 @@ BaseGDL* Data_<SpDObj>::NewIx( SizeT ix)
 
   if( desc->IsParent("LIST"))
   {
-      static DString cNodeName("GDL_CONTAINER_NODE");
       // because of .RESET_SESSION, we cannot use static here
       DStructDesc* containerDesc=structDesc::GDL_CONTAINER_NODE;
     
       // no static here, might vary in derived object
 //       unsigned pHeadTag = desc->TagIndex( "PHEAD");
-      static unsigned pTailTag = desc->TagIndex( "PTAIL");
+      unsigned pTailTag = desc->TagIndex( "PTAIL");
 
+      // these are fixed as GDL_CONTAINER_NODE is (should be) private - probably to be replaced by a std::map 
       static unsigned pNextTag = structDesc::GDL_CONTAINER_NODE->TagIndex( "PNEXT");
       static unsigned pDataTag = structDesc::GDL_CONTAINER_NODE->TagIndex( "PDATA");
 //       unsigned nListTag = desc->TagIndex( "NLIST");
@@ -1353,7 +1353,7 @@ Data_<SpDPtr>* Data_<SpDPtr>::NewIx( AllIxBaseT* ix, const dimension* dIn)
 {
   SizeT nCp = ix->size();
   Data_* res=Data_::New( *dIn, BaseGDL::NOZERO);
-  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
   {
     //#pragma omp for
     for( SizeT c=0; c<nCp; ++c)
@@ -1370,7 +1370,7 @@ Data_<SpDObj>* Data_<SpDObj>::NewIx( AllIxBaseT* ix, const dimension* dIn)
 {
   SizeT nCp = ix->size();
   Data_* res=Data_::New( *dIn, BaseGDL::NOZERO);
-  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
   {
     //#pragma omp for
     for( SizeT c=0; c<nCp; ++c)
@@ -1388,7 +1388,7 @@ Data_<SpDPtr>* Data_<SpDPtr>::NewIxFrom( SizeT s)
 {
   SizeT nCp = dd.size() - s;
   Data_* res=Data_::New( dimension( nCp), BaseGDL::NOZERO);
-  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
   {
     //#pragma omp for
     for( SizeT c=0; c<nCp; ++c)
@@ -1405,7 +1405,7 @@ Data_<SpDObj>* Data_<SpDObj>::NewIxFrom( SizeT s)
 {
   SizeT nCp = dd.size() - s;
   Data_* res=Data_::New( dimension( nCp), BaseGDL::NOZERO);
-  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
   {
     //#pragma omp for
     for( SizeT c=0; c<nCp; ++c)
@@ -1423,7 +1423,7 @@ Data_<SpDPtr>* Data_<SpDPtr>::NewIxFrom( SizeT s, SizeT e)
 {
   SizeT nCp = e - s + 1;
   Data_* res=Data_::New( dimension( nCp), BaseGDL::NOZERO);
-  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
   {
     //#pragma omp for
     for( SizeT c=0; c<nCp; ++c)
@@ -1441,7 +1441,7 @@ Data_<SpDObj>* Data_<SpDObj>::NewIxFrom( SizeT s, SizeT e)
 {
   SizeT nCp = e - s + 1;
   Data_* res=Data_::New( dimension( nCp), BaseGDL::NOZERO);
-  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS <= nCp))
+  //#pragma omp parallel if (nCp >= CpuTPOOL_MIN_ELTS && (CpuTPOOL_MAX_ELTS == 0 || CpuTPOOL_MAX_ELTS >= nCp))
   {
     //#pragma omp for
     for( SizeT c=0; c<nCp; ++c)
