@@ -16,11 +16,6 @@
  ***************************************************************************/
 
 #include "includefirst.hpp"
-
-// #ifndef VERSION
-// #define VERSION "0.9"
-// #endif
-
 #include <string>
 #include <csignal>
 #include <cstdlib>
@@ -42,8 +37,8 @@
 #include "str.hpp"
 #include "dinterpreter.hpp"
 #include "terminfo.hpp"
-#include "sigfpehandler.hpp"
 #include "gdleventhandler.hpp"
+#include "gdl2gdl.hpp"
 
 #ifdef _OPENMP
 #include <omp.h>
@@ -66,14 +61,10 @@
 //initialize wxWidgets system:  create an instance of wxAppGDL
 #ifdef HAVE_LIBWXWIDGETS
 #include "gdlwidget.hpp"
-//displaced in gdlwidget.cpp to make wxGetApp() available under Python (in GDL.so)
-//#ifndef __WXMAC__ 
-//wxIMPLEMENT_APP_NO_MAIN( wxAppGDL);
-//#else
-//wxIMPLEMENT_APP_NO_MAIN( wxApp);
-//#endif
 #endif
 
+#include "version.hpp"
+
 using namespace std;
 
 static void StartupMessage()
@@ -95,38 +86,35 @@ void SetGDLGenericGSLErrorHandler(); // defined in gsl_fun.cpp
 void InitOpenMP() {
 #ifdef _OPENMP
   int suggested_num_threads, omp_num_core;  
-  suggested_num_threads=get_suggested_omp_num_threads();
-  omp_num_core=omp_get_num_procs();
+//  suggested_num_threads=get_suggested_omp_num_threads();
+//  omp_num_core=omp_get_num_procs();
 
   //  cerr << "estimated Threads :" << suggested_num_threads << endl;
 
   // we update iff needed (by default, "omp_num_threads" is initialiazed to "omp_num_core"
-  if ((suggested_num_threads > 0) && (suggested_num_threads < omp_num_core)) {
-
-    // update of !cpu.TPOOL_NTHREADS
-    DStructGDL* cpu = SysVar::Cpu();
-    static unsigned NTHREADSTag = cpu->Desc()->TagIndex( "TPOOL_NTHREADS");
-    (*static_cast<DLongGDL*>( cpu->GetTag( NTHREADSTag, 0)))[0] =suggested_num_threads;
-
-    // effective global change of num of treads using omp_set_num_threads()
-    CpuTPOOL_NTHREADS=suggested_num_threads;
-    omp_set_num_threads(suggested_num_threads);
-  } else {
+//  if ((suggested_num_threads > 0) && (suggested_num_threads < omp_num_core)) {
+//
+//    // update of !cpu.TPOOL_NTHREADS
+//    DStructGDL* cpu = SysVar::Cpu();
+//    static unsigned NTHREADSTag = cpu->Desc()->TagIndex( "TPOOL_NTHREADS");
+//    (*static_cast<DLongGDL*>( cpu->GetTag( NTHREADSTag, 0)))[0] =suggested_num_threads;
+//
+//    // effective global change of num of treads using omp_set_num_threads()
+//    CpuTPOOL_NTHREADS=suggested_num_threads;
+//    omp_set_num_threads(suggested_num_threads);
+//  } else {
     CpuTPOOL_NTHREADS=omp_get_num_procs();
     omp_set_num_threads(CpuTPOOL_NTHREADS);
-  }
+//  }
   //  cout << CpuTPOOL_NTHREADS <<endl;
 #endif
 }
 
 void AtExit()
 {
-  //this function probably cleans otherwise cleaned objets and should be called only for debugging purposes.
-  cerr << "Using AtExit() for debugging" << endl;
-  cerr << flush; cout << flush; clog << flush;
-  // clean up everything
-  // (for debugging memory leaks)
-  ResetObjects();
+  //this function cleans objets and should be called only for debugging purposes.(for debugging memory leaks)
+  // enabled with flag --clean-at-exit
+  ResetObjects(true);
   PurgeContainer(libFunList);
   PurgeContainer(libProList);
 }
@@ -135,13 +123,13 @@ void AtExit()
 void GDLSetLimits()
 {
 #define GDL_PREFERED_STACKSIZE  1024000000 //1000000*1024 like IDL
-struct rlimit* gdlstack=new struct rlimit;
-  int r=getrlimit(RLIMIT_STACK,gdlstack); 
+struct rlimit gdlstack;
+  int r=getrlimit(RLIMIT_STACK,&gdlstack); 
 //  cerr <<"Current rlimit = "<<gdlstack->rlim_cur<<endl;
 //  cerr<<"Max rlimit = "<<  gdlstack->rlim_max<<endl;
-  if (gdlstack->rlim_cur >= GDL_PREFERED_STACKSIZE ) return; //the bigger the better.
-  if (gdlstack->rlim_max > GDL_PREFERED_STACKSIZE ) gdlstack->rlim_cur=GDL_PREFERED_STACKSIZE; //not completely satisfactory.
-  r=setrlimit(RLIMIT_STACK,gdlstack);
+  if (gdlstack.rlim_cur >= GDL_PREFERED_STACKSIZE ) return; //the bigger the better.
+  if (gdlstack.rlim_max > GDL_PREFERED_STACKSIZE ) gdlstack.rlim_cur=GDL_PREFERED_STACKSIZE; //not completely satisfactory.
+  r=setrlimit(RLIMIT_STACK,&gdlstack);
 }
 #endif
 
@@ -165,6 +153,7 @@ void InitGDL()
   //Our handler takes too long
   //when editing the command line with ARROW keys. (bug 562). (used also in dinterpreted.cpp )
   //but... without it we have no graphics event handler! FIXME!!! 
+  rl_set_keyboard_input_timeout (GDL_INPUT_TIMEOUT);
   rl_event_hook = GDLEventHandler;
 #endif
 
@@ -176,19 +165,13 @@ void InitGDL()
 
   // init library functions
   LibInit(); 
-    
+  
   // ensuring we work in the C locale (needs to be called after InitObjects and LibInit!!! 
   // as some code there calls setlocale as well, e.g. MagickInit)
 #ifdef HAVE_LOCALE_H
   setlocale(LC_ALL, "C");
 #endif
 
-  // turn on all floating point exceptions
-  //  feenableexcept(FE_DIVBYZERO | FE_INVALID | FE_OVERFLOW );
-
-  signal(SIGINT,ControlCHandler);
-  signal(SIGFPE,SigFPEHandler);
-  
   lib::SetGDLGenericGSLErrorHandler();
 }
 
@@ -234,94 +217,49 @@ namespace MyPaths {
     std::string pathstring(path);
     free(path);
     return pathstring;
-  }
+    }
   return std::string(".");
 }
 }
 
-
 int main(int argc, char *argv[])
 {
-#ifdef GDL_DEBUG
-  if( atexit( AtExit) != 0) cerr << "atexit registration failed." << endl;
-#endif
+
   // indicates if the user wants to see the welcome message
   bool quiet = false;
   bool gdlde = false;
-
+  bool setQuietSysvar=false;
+  bool willSuppressEditInput=false;
+  std::string myMessageBoxName="";
+  
 //The default installation location --- will not always be there.  
   gdlDataDir = std::string(GDLDATADIR);
-  gdlLibDir = std::string(GDLLIBDIR);
 #ifdef _WIN32
   std::replace(gdlDataDir.begin(), gdlDataDir.end(), '/', '\\');
-  std::replace(gdlLibDir.begin(), gdlLibDir.end(), '/', '\\');
 #endif 
 
 //check where is the executable being run
- std::string whereami=MyPaths::getExecutablePath();
+ whereami_gdl=MyPaths::getExecutablePath();
 // if I am at a 'bin' location, then there are chances that I've bee INSTALLED, so all the resources I need can be accessed relatively to this 'bin' directory.
 // if not, then I'm probably just a 'build' gdl and my ressources may (should?) be in the default location GDLDATADIR
-  std::size_t pos=whereami.rfind("bin");
-  if (pos == whereami.size()-3) { //we are the installed gdl!
-    gdlDataDir.assign( whereami+ lib::PathSeparator() + ".." + lib::PathSeparator() + "share" + lib::PathSeparator() + "gnudatalanguage") ;
+  std::size_t pos=whereami_gdl.rfind("bin");
+  if (pos == whereami_gdl.size()-3) { //we are the installed gdl!
+    gdlDataDir.assign( whereami_gdl+ lib::PathSeparator() + ".." + lib::PathSeparator() + "share" + lib::PathSeparator() + "gnudatalanguage") ;
 //    std::cerr<<"installed at: "<<gdlDataDir<<std::endl;
   }
 
-//PATH. This one is often modified by people before starting GDL.
-  string gdlPath=GetEnvPathString("GDL_PATH"); //warning: is a Path, use system separator.
-  if( gdlPath == "") gdlPath=GetEnvString("IDL_PATH"); //warning: is a Path, use system separator.
-  if( gdlPath == "") gdlPath = gdlDataDir + lib::PathSeparator() + "lib";
+//   GD: seems to confuse people --- too much information kills information
+//  bool pathUserNotDefined=false;
+//  string gdlPath=GetEnvPathString("GDL_PATH"); //warning: is a Path, use system separator.
+//  if( gdlPath == "") gdlPath=GetEnvPathString("IDL_PATH"); //warning: is a Path, use system separator.
+//  if( gdlPath == "") {
+//    gdlPath = "+" + gdlDataDir + lib::PathSeparator() + "lib";
+//    pathUserNotDefined=true;
+//  }
 
-//LIBDIR. Can be '' in which case the location of drivers is deduced from the location of
-//the executable (OSX, Windows, unix in user-installed mode).
-  string driversPath = GetEnvPathString("GDL_DRV_DIR");
-  if (driversPath == "") { //NOT enforced by GDL_DRV_DIR
-    driversPath = gdlLibDir; //e.g. Fedora
-    if (driversPath == "") { //NOT enforced by GDLLIBDIR at build : not a distro
-      driversPath = gdlDataDir + lib::PathSeparator() + "drivers"; //deduced from the location of the executable 
-    }
-  }
-  //drivers if local
-  useLocalDrivers=false;
-  bool driversNotFound=false;
-
-  //The current value for PLPLOT_DRV_DIR.
-  //To find our drivers, the plplot library needs to have PLPLOT_DRV_DIR set to the good path, i.e., driversPath.
-  const char* DrvEnvName = "PLPLOT_DRV_DIR";
-  //In a startup message (below), the value of $PLPLOT_DRV_DIR appears.
-  //It will be the value set inside the program (just below) to find the relevant drivers.
-
-#ifdef INSTALL_LOCAL_DRIVERS
-  useLocalDrivers=true;
-  //For WIN32 the drivers dlls are copied along with the gdl.exe and plplot does not use PLPLOT_DRV_DIR to find them.
-#ifndef _WIN32
-  char* oldDriverEnv=getenv(DrvEnvName);
-  // We must declare here (and not later) where our local copy of (customized?) drivers is to be found.
-  char s[256];
-  strcpy(s,DrvEnvName);
-  strcat(s,"=");
-  strcat(s,driversPath.c_str());
-      //set nex drvPath as PLPLOT_DRV_DIR
-  putenv(s);
-  //Now, it is possible that GDL WAS compiled with INSTALL_LOCAL_DRIVERS, but the plplot installation is NOT compiled with DYNAMIC DRIVERS.
-  //So I check here the plplot driver list to check if wxwidgets is present. If not, useLocalDriver=false
-  bool driversOK=GDLGStream::checkPlplotDriver("ps"); //ps because xwin and wxwidgets may be absent. ps is always present.
-  if (!driversOK) {
-    driversNotFound=true; 
-    useLocalDrivers=false;
-    unsetenv(DrvEnvName); //unknown on windows
-    //eventually restore previous value
-    if (oldDriverEnv) {
-      strcpy(s,DrvEnvName);
-      strcat(s,"=");
-      strcat(s,oldDriverEnv);
-      putenv(s);
-    }
-    plend(); //this is necessary to reset PLPLOT to a state that will read again the driver configuration at PLPLOT_DRV_DIR
-             // otherwise the next call to checkPlplotDriver() in GDLWxStream will fail.
-  }
-#endif
-#endif
+  char* wantCalm = getenv("IDL_QUIET");
+  if (wantCalm != NULL) setQuietSysvar=true;
+  
   // keeps a list of files to be executed after the startup file
   // and before entering the interactive mode
   vector<string> batch_files;
@@ -335,6 +273,7 @@ int main(int argc, char *argv[])
   tryToMimicOriginalWidgets = false;
   useDSFMTAcceleration = true;
   iAmANotebook=false; //option --notebook
+  iAmMaster=true; //special option --subprocess
  #ifdef HAVE_LIBWXWIDGETS 
 
     #if defined (__WXMAC__) 
@@ -353,7 +292,7 @@ int main(int argc, char *argv[])
 #endif
   for( SizeT a=1; a< argc; ++a)
     {
-      if( string( argv[a]) == "--help" | string( argv[a]) == "-h") {
+      if( string( argv[a]) == "--help" || string( argv[a]) == "-h") {
       cerr << "Usage: gdl [ OPTIONS ] [ batch_file ... ]" << endl;
       cerr << "Start the GDL interpreter (incremental compiler)" << endl;
       cerr << endl;
@@ -361,12 +300,7 @@ int main(int argc, char *argv[])
       cerr << "  --help (-h)        display this message" << endl;
       cerr << "  --version (-V, -v) show version information" << endl;
       cerr << "  --fakerelease X.y  pretend that !VERSION.RELEASE is X.y" << endl;
-      cerr << "  --fussy            implies that procedures adhere with modern IDL, where \"()\" are for functions and \"[]\" are for arrays." << endl;
-      cerr << "                     This speeds up (sometimes terribly) compilation but choke on every use of \"()\" with arrays." << endl;
-      cerr << "                     Conversion of procedures to modern IDL can be done with D. Landsman's idlv4_to_v5 procedure." << endl;
-      cerr << "                     Use enviromnment variable \"GDL_IS_FUSSY\" to set up permanently this feature." << endl;
-      cerr << "  --sloppy           Sets the traditional (default) compiling option where \"()\"  can be used both with functions and arrays." << endl;
-      cerr << "                     Needed to counteract temporarily the effect of the enviromnment variable \"GDL_IS_FUSSY\"." << endl;
+      cerr << "  --trace-old-syntax print lines that do not adhere with modern IDL, where \"()\" are for functions and \"[]\" are for arrays." << endl;
       cerr << "  --MAC              Graphic device will be called 'MAC' on MacOSX. (default: 'X')" << endl;
       cerr << "  [--no-use-wx | -X] Tells GDL not to use WxWidgets graphics and resort to X11 (if available)." << endl;
       cerr << "                     Also enabled by setting the environment variable GDL_DISABLE_WX_PLOTS to a non-null value." << endl;
@@ -377,7 +311,9 @@ int main(int argc, char *argv[])
       cerr << "  --no-dSFMT         Tells GDL not to use double precision SIMD oriented Fast Mersenne Twister(dSFMT) for random doubles." << endl;
       cerr << "                     Also disable by setting the environment variable GDL_NO_DSFMT to a non-null value." << endl;
       cerr << "  --with-eigen-transpose lets GDL use Eigen::transpose and related functions instead of our accelerated transpose function. Normally slower." <<endl;
-      cerr << "  --smart-tpool      switch to a mode where the number of threads is adaptive (experimental). Should enable better perfs on many core machines." <<endl;
+      cerr << "  --smart-tpool      switch to a mode where the number of threads is adaptive (DEFAULT). Should enable better perfs on many core machines." <<endl;
+      cerr << "  --no-smart-tpool   switch to a mode where the number of threads is NOT adaptive." <<endl;
+      cerr << "  --silent           Supresses some messages (mainly \"Compiled Module XXX\" ." <<endl;
 #ifdef _WIN32
       cerr << "  --posix (Windows only): paths will be posix paths (experimental)." << endl;
 #endif
@@ -395,7 +331,7 @@ int main(int argc, char *argv[])
       cerr << "Homepage: https://gnudatalanguage.github.io" << endl;
       return 0;
     }
-      else if (string(argv[a])=="--version" | string(argv[a])=="-v" | string(argv[a])=="-V")
+      else if (string(argv[a])=="--version" || string(argv[a])=="-v" || string(argv[a])=="-V")
 	{
 	  cerr << "GDL - GNU Data Language, Version " << VERSION << endl;
 	  return 0;
@@ -414,7 +350,7 @@ int main(int argc, char *argv[])
         for (int i = a + 1; i < argc; i++) lib::command_line_args.push_back(string(argv[i]));
         break;
       }
-      else if (string(argv[a])=="-quiet" | string(argv[a])=="--quiet" | string(argv[a])=="-q") 
+      else if (string(argv[a])=="-quiet" || string(argv[a])=="--quiet" || string(argv[a])=="-q") 
 	{
 	  quiet = true;
 	}
@@ -460,14 +396,8 @@ int main(int argc, char *argv[])
       {
           gdlde = true;
       }
-      else if (string(argv[a]) == "--fussy")
+      else if (string(argv[a]) == "--trace-old-syntax")
       {
-          strict_syntax = true;
-          syntaxOptionSet = true;
-      }
-      else if (string(argv[a]) == "--sloppy")
-      {
-          strict_syntax = false;
           syntaxOptionSet = true;
       }
       else if (string(argv[a]) == "--no-dSFMT")
@@ -485,7 +415,7 @@ int main(int argc, char *argv[])
       {
          usePlatformDeviceName = true;
       }
-      else if (string(argv[a]) == "--no-use-wx" |  string(argv[a]) == "-X")
+      else if (string(argv[a]) == "--no-use-wx" ||  string(argv[a]) == "-X")
       {
          force_no_wxgraphics = true;
       }
@@ -493,6 +423,10 @@ int main(int argc, char *argv[])
       {
          useEigenForTransposeOps = true;
       }
+      else if (string(argv[a]) == "--no-smart-tpool")
+      {
+         useSmartTpool = false;
+      }
       else if (string(argv[a]) == "--smart-tpool")
       {
          useSmartTpool = true;
@@ -501,6 +435,21 @@ int main(int argc, char *argv[])
       {
          iAmANotebook = true;
       }
+      else if (string(argv[a]) == "--silent")
+      {
+         setQuietSysvar=true;
+      }
+      else if (string(argv[a]) == "--subprocess") {
+		if (a == argc - 1) {
+		  cerr << "gdl: --subprocess must be followed by the parent's pid" << endl;
+		  return 0;
+		}
+		myMessageBoxName = argv[++a];
+	  	iAmMaster = false;
+		setQuietSysvar = true;
+		willSuppressEditInput = true;
+		//		 std::cerr<<"I am a SubProcess"<<std::endl;
+	  }
       else if (string(argv[a]) == "--fakerelease")
       {
         if (a == argc - 1)
@@ -509,12 +458,21 @@ int main(int argc, char *argv[])
             return 0;
           }
         pretendRelease = string(argv[++a]);
-      }
-      else if (*argv[a] == '-')
-      {
+	} else if (string(argv[a]) == "--clean-at-exit") {
+	  if (atexit(AtExit) != 0) cerr << "atexit registration failed. option \"--clean-at-exit\" unefficient." << endl;
+	} else if (*argv[a] == '-') {
+      if (string(argv[a],5)=="-IDL_" || string(argv[a],5)=="-GDL_") { //an IDL/GDL preference ? do it.
+      char* what=argv[a];
+#if defined(_WIN32)
+        int ret=_putenv_s( (char*)(what+1), argv[++a]); //overwrite
+#else
+        int ret=setenv( (char*)(what+1), argv[++a], 1); //overwrite
+#endif
+      } else {
         cerr << argv[0] << ": " << argv[a] << " option not recognized." << endl;
         return 0;
       }
+      }
       else
       {
         batch_files.push_back(argv[a]);
@@ -526,6 +484,9 @@ int main(int argc, char *argv[])
     cerr << argv[0] << ": " << "-e option cannot be specified with batch files" << endl;
     return 0;
   }
+
+  //depending on master or not, attach to respective message boxes
+  if (!iAmMaster) gdl_ipc_ClientGetsMailboxAddress(myMessageBoxName);	
   
   //before InitGDL() as InitGDL() starts graphic!
   
@@ -544,10 +505,27 @@ int main(int argc, char *argv[])
   if (force_no_wxgraphics) useWxWidgetsForGraphics=false; //this has the last answer, whatever the setup.
 #endif  
   std::string doUseUglyFonts=GetEnvString("GDL_WIDGETS_COMPAT");
-  if ( doUseUglyFonts.length() > 0) tryToMimicOriginalWidgets=true; 
-  
-  InitGDL(); 
+  if ( doUseUglyFonts.length() > 0) tryToMimicOriginalWidgets=true;
 
+  InitGDL(); 
+  
+  // for debug one could turn on all floating point exceptions, it will stop at first one.
+  //  feenableexcept(FE_DIVBYZERO | FE_INVALID | FE_OVERFLOW );
+
+  
+#if !defined(_WIN32)
+  if (iAmMaster) {
+	signal(SIGINT, ControlCHandler); 
+	signal(SIGCHLD,SIG_IGN); //end subprocess is by sending it 'EXIT'. 
+	                         //This should avoid zombies after a IDL_IDLBridge::Cleanup for example.
+	                         // but we do not trap a subprocess crashing, which may be desirable!
+	// BUT we would need to trap on every case it must be used in gdl2gdl.cpp, including ABORT and EXIT commands
+	// "Normally" there should be few problems if every other place wait() is used in GDL has temporarily correctly set
+	// the SIGCHLD signal handler to SIG_DFL before use and reset it to these defaulst after use.
+	// An obvious improvement would be to get rid of all signal handlers in gdl2gdl.
+  } else signal(SIGINT, ChildControlCHandler);
+#endif
+  
   // must be after !cpu initialisation
   InitOpenMP(); //will supersede values for CpuTPOOL_NTHREADS
 
@@ -556,15 +534,12 @@ int main(int argc, char *argv[])
 
   if (gdlde || (isatty(0) && !quiet)) {
     StartupMessage();
-    cerr << "- Default library routine search path used (GDL_PATH/IDL_PATH env. var. not set): " << gdlPath << endl;
+//    if (pathUserNotDefined) cerr << "- Default library routine search path used (GDL_PATH/IDL_PATH env. var. not set): " << gdlPath << endl;
     if (useWxWidgetsForGraphics) cerr << "- Using WxWidgets as graphics library (windows and widgets)." << endl;
-    if (useLocalDrivers || driversNotFound) {
-      if (driversNotFound) cerr << "- Local drivers not found --- using default ones. " << endl;
-      else if (getenv(DrvEnvName)) cerr << "- Using local drivers in " << getenv(DrvEnvName) << endl; //protect against NULL.
-    }
   }
   if (useDSFMTAcceleration && (GetEnvString("GDL_NO_DSFMT").length() > 0)) useDSFMTAcceleration=false;
-  
+  if (setQuietSysvar)       SysVar::Make_Quiet();
+  if (willSuppressEditInput)		 SysVar::Suppress_Edit_Input();  
   //report in !GDL status struct
   DStructGDL* gdlconfig = SysVar::GDLconfig();
   unsigned  DSFMTTag= gdlconfig->Desc()->TagIndex("GDL_USE_DSFMT");
@@ -575,12 +550,10 @@ int main(int argc, char *argv[])
   (*static_cast<DByteGDL*> (gdlconfig->GetTag(useWXTAG, 0)))[0]=useWxWidgetsForGraphics;
   
   if (!pretendRelease.empty()) SysVar::SetFakeRelease(pretendRelease);
-  //fussyness setup and change if switch at start
-  if (syntaxOptionSet) { //take it no matters any env. var.
-    if (strict_syntax == true) SetStrict(true);
-  } else {
-    if (GetEnvString("GDL_IS_FUSSY").size()> 0) SetStrict(true);
-  }
+  //trace old syntax locations in procedures.
+  if (syntaxOptionSet) { 
+    SetTraceSyntaxErrors(true);
+  } else SetTraceSyntaxErrors(false);
   
   
   string startup=GetEnvPathString("GDL_STARTUP");
@@ -610,6 +583,7 @@ int main(int argc, char *argv[])
 //     }
 
 #ifdef USE_MPI
+  if (iAmMaster) {
   {
     // warning the user if MPI changes the working directory of GDL
     char wd1[PATH_MAX], wd2[PATH_MAX];
@@ -632,8 +606,14 @@ int main(int argc, char *argv[])
       MPI_Send(mpi_procedure, strlen(mpi_procedure)+1, MPI_CHAR, i, 
 	       tag, MPI_COMM_WORLD);
   }
+  }
 #endif // USE_MPI
-
+  
+  //always between try{} catch{} when calling ExecuteStringLine!
+  try {
+  std::string dlmCommand=("dlm_register,/silent");
+  interpreter.ExecuteStringLine(dlmCommand);
+  } catch (...) {std::cerr<<"Problem starting DLMs\n";}
   interpreter.InterpreterLoop( startup, batch_files, statement);
 
   return 0;
