@@ -144,9 +144,6 @@ static const std::string axisName[6] = {"X", "Y", "Z", "X", "Y", "Z"};
 struct GDL_TICKDATA {
   GDLGStream *a;
   EnvT *e;
-  bool isLog;
-  DDouble axisrange; //to circumvent plplot passing a non-zero value instead of strict 0.0
-  double nchars; //length of string *returned* after formatting. Can be non-integer.
   // For TICKNAMES
   SizeT tickNameCounter; //internal counter of what tickname we use
   SizeT nTickName; //number of tickname values passed
@@ -158,9 +155,14 @@ struct GDL_TICKDATA {
   SizeT nTickUnits;
   DStringGDL* TickUnits;
   SizeT counter;
-  bool reset; //reset internal counter each time a new 'axis' command is issued
+  DDouble Start; //used where the span of values in axis matters.
+  DDouble End; //used where the spand of values in axis matters.
+  double nchars; //length of string *returned* after formatting. Can be non-integer.
   int tickOptionCode;
   int tickLayoutCode;
+  int maxPrec;
+  bool isLog;
+  bool reset; //reset internal counter each time a new 'axis' command is issued
 };
 
 
@@ -232,8 +234,11 @@ namespace lib {
   void SelfPDotTTransformXYZ(DDoubleGDL *xt, DDoubleGDL *yt, DDoubleGDL *zt);
   void PDotTTransformXYZval(PLFLT x, PLFLT y, PLFLT *xt, PLFLT *yt, PLPointer data);
   DDoubleGDL* gdlDefinePlplotRotationMatrix(DDouble az, DDouble alt, DDouble *scale, bool save);
-  bool gdlInterpretT3DMatrixAsPlplotRotationMatrix(DDouble &az, DDouble &alt, DDouble &ay, DDouble *scale, T3DEXCHANGECODE &axisExchangeCode, bool &below);
+  void gdlMakeSubpageRotationMatrix3d(DDoubleGDL* me, PLFLT xratio, PLFLT yratio, PLFLT zratio, PLFLT* trans);
+  void gdlMakeSubpageRotationMatrix2d(DDoubleGDL* me, PLFLT xratio, PLFLT yratio, PLFLT zratio, PLFLT* trans, PLFLT shift=0, bool invert=false);
+  bool gdlInterpretT3DMatrixAsPlplotRotationMatrix(DDouble &az, DDouble &alt, DDouble &ay, DDouble *scale, /* DDouble *trans,*/  T3DEXCHANGECODE &axisExchangeCode, bool &below);
   DDoubleGDL* gdlGetT3DMatrix();
+  void get3DMatrixParametersFor2DPosition(PLFLT &xratio, PLFLT &yratio, PLFLT &zratio, PLFLT* displacement);
   void gdlStartT3DMatrixDriverTransform(GDLGStream *a, DDouble zValue);
   void gdlStartSpecial3DDriverTransform( GDLGStream *a, GDL_3DTRANSFORMDEVICE &PlotDevice3D);
   void gdlExchange3DDriverTransform( GDLGStream *a);
@@ -250,7 +255,13 @@ namespace lib {
   void GDLgrPlotProjectedPolygon(GDLGStream * a, DDoubleGDL *lonlat, bool const doFill, DLongGDL *conn);
   void gdlSetGraphicsPenColorToBackground(GDLGStream *a);
   void gdlLineStyle(GDLGStream *a, DLong style);
-  DFloat* gdlGetRegion();
+  PLFLT* gdlGetRegion();
+  PLFLT gdlGetBoxNXSize(); // what !X thinks the current PLOT box size is, in normalised coordinates. To be used instead of the boxnXSize() gdlgstream function whenever possible.
+  PLFLT gdlGetBoxNYSize(); // what !Y thinks the current PLOT box size is, in normalised coordinates. To be used instead of the boxnYSize() gdlgstream function whenever possible.
+  DFloat* gdlGetWindow();
+  void gdlStoreXAxisRegion(GDLGStream* actStream, PLFLT* r);
+  void gdlStoreYAxisRegion(GDLGStream* actStream, PLFLT* r);
+  void gdlStoreZAxisRegion(GDLGStream* actStream, PLFLT* r);
   void gdlStoreXAxisParameters(GDLGStream* actStream, DDouble Start, DDouble End, bool log);
   void gdlStoreYAxisParameters(GDLGStream* actStream, DDouble Start, DDouble End, bool log);
   void gdlStoreZAxisParameters(GDLGStream* actStream, DDouble Start, DDouble End, bool log, DDouble zposStart, DDouble zposEnd);
@@ -268,14 +279,15 @@ namespace lib {
   void GetCurrentUserLimits(DDouble &xStart, DDouble &xEnd, DDouble &yStart, DDouble &yEnd); //2D
   void GetCurrentUserLimits(DDouble &xStart, DDouble &xEnd, DDouble &yStart, DDouble &yEnd, DDouble &zStart, DDouble &zEnd); //3D
   void gdlAdjustAxisRange(EnvT* e, int axisId, DDouble &val_min, DDouble &val_max, bool &log);
-  PLFLT AutoTick(DDouble x);
-  PLFLT AutoLogTick(DDouble min, DDouble max);
+  PLFLT AutoTickIntv(DDouble x, bool freeRange=false);
+  PLFLT AutoLogTickIntv(DDouble min, DDouble max);
   void setIsoPort(GDLGStream* actStream, PLFLT x1, PLFLT x2, PLFLT y1, PLFLT y2, PLFLT aspect);
   void GetMinMaxVal(DDoubleGDL* val, double* minVal, double* maxVal);
   void GetMinMaxValuesForSubset(DDoubleGDL* val, DDouble &minVal, DDouble &maxVal, SizeT endElement);
   void UpdateSWPlotStructs(GDLGStream* actStream, DDouble xStart, DDouble xEnd, DDouble yStart,
     DDouble yEnd, bool xLog, bool yLog);
   DDoubleGDL* getLabelingValues(int axisId);
+  DDoubleGDL* computeLabelingValues(int axisId);
   void defineLabeling(GDLGStream *a, int axisId, void(*func)(PLINT axis, PLFLT value, char *label, PLINT length, PLPointer data), PLPointer data);
   void resetLabeling(GDLGStream *a, int axisId);
   void gdlSimpleAxisTickFunc(PLINT axis, PLFLT value, char *label, PLINT length, PLPointer data);
@@ -309,11 +321,9 @@ namespace lib {
   private:
     virtual bool handle_args(EnvT*) = 0; // return value = overplot
     virtual bool prepareDrawArea(EnvT*, GDLGStream*) = 0;
-    virtual void applyGraphics(EnvT*, GDLGStream*) = 0;
+    virtual void applyGraphics(EnvT*, GDLGStream*) = 0;  //Should *NOT* contain any 'save' commands able to change !X,!Y,!Z,!P,!D values !!!! 
     virtual void post_call(EnvT*, GDLGStream*) = 0;
 
-    void restoreDrawArea(GDLGStream *a);
-
     // all steps combined (virtual methods cannot be called from ctor)
   public:
     void call(EnvT* e, SizeT n_params_required);
@@ -323,6 +333,7 @@ namespace lib {
   //This because static pointers to options indexes are needed to speed up process, but these indexes vary between
   //the definition of the caller functions (e.g. "CHARSIZE" is 1 for CONTOUR but 7 for XYOUTS). So they need to be kept
   //static (for speed) but private for each graphic command.
+  void restoreDrawArea(GDLGStream *a);
 
   void gdlSetGraphicsBackgroundColorFromKw(EnvT *e, GDLGStream *a, bool kw = true);
 
@@ -334,11 +345,11 @@ namespace lib {
 
   void gdlSetSymsize(EnvT *e, GDLGStream *a);
 
-  void gdlSetPlotCharsize(EnvT *e, GDLGStream *a, bool accept_sizeKw = false);
+  void gdlSetPlotCharsize(EnvT *e, GDLGStream *a, PLFLT use_factor = 1, bool accept_sizeKw = false);
 
   void gdlSetPlotCharthick(EnvT *e, GDLGStream *a);
   
-  PLFLT gdlComputeTickInterval(EnvT *e, int axisId, DDouble &min, DDouble &max, bool log, int level=0);
+  PLFLT gdlComputeAxisTickInterval(EnvT *e, int axisId, DDouble min, DDouble max, bool log, int level=0, bool freeRange=false);
 
   void gdlGetDesiredAxisCharsize(EnvT* e, int axisId, DFloat &charsize);
 
@@ -356,8 +367,6 @@ namespace lib {
 
   void gdlGetDesiredAxisThick(EnvT *e, int axisId, DFloat &thick);
 
-  void gdlGetDesiredAxisTickget(EnvT *e, int axisId, DDoubleGDL *Axistickget);
-
   void gdlGetDesiredAxisTickFormat(EnvT* e, int axisId, DStringGDL* &axisTickformatVect);
 
   void gdlGetDesiredAxisTickInterval(EnvT* e, int axisId, DDouble &axisTickinterval);
@@ -379,7 +388,7 @@ namespace lib {
 
   //if [X|Y|Z]TICK_GET was given for axis, write the values.
 
-  void gdlWriteDesiredAxisTickGet(EnvT* e, int axisId, bool isLog);
+  void gdlGetDesiredAxisTickGet(EnvT* e, int axisId, DDouble TickInterval, DDouble Start, DDouble End, bool isLog);
 
   void gdlGetDesiredAxisTitle(EnvT *e, int axisId, DString &title);
 
@@ -398,7 +407,7 @@ namespace lib {
   //advance to next plot unless the noerase flag is set
   // function declared static (local to each function using it) to avoid messing the NOERASEIx index which is not the same.
 
-  void gdlNextPlotHandlingNoEraseOption(EnvT *e, GDLGStream *a, bool noe = false);
+  void gdlNextPlotHandlingNoEraseOption(EnvT *e, GDLGStream *a);
 
   //handling of Z bounds is not complete IMHO.
 
@@ -435,7 +444,7 @@ namespace lib {
 
   void gdlBox(EnvT *e, GDLGStream *a, DDouble xStart, DDouble xEnd, bool xLog, DDouble yStart, DDouble yEnd, bool yLog);
   
-  void gdlBox3(EnvT *e, GDLGStream *a, DDouble xStart, DDouble xEnd, bool xLog, DDouble yStart, DDouble yEnd, bool yLog,  DDouble zStart, DDouble zEnd, bool zLog, DDouble zValue);
+  void gdlBox3(EnvT *e, GDLGStream *a, DDouble xStart, DDouble xEnd, bool xLog, DDouble yStart, DDouble yEnd, bool yLog,  DDouble zStart, DDouble zEnd, bool zLog, DDouble zValue, bool drawZ=false, DLong zcode=0);
    
   //restore current clipbox, make another or remove it at all.
   bool gdlSwitchToClippedNormalizedCoordinates(EnvT *e, GDLGStream *actStream, bool invertedClipMeaning=false, bool commandHasCoordSys=true );
